@@ -35,12 +35,8 @@ var namespace_ogre_1_1_volume =
     [ "VecDualCell", "group___volume.html#gaba362e5d4ee54e19d9f7025c2a9c7e85", null ],
     [ "Vertex", "group___volume.html#ga89f21806decd3e6441190d071eed6a5c", null ],
     [ "VecVertex", "group___volume.html#ga42533278f4be6a1aeae58d18255d0ca1", null ],
-    [ "VecIndices", "group___volume.html#ga00db3f974951d99d4a0902580eeb8151", null ],
+    [ "VecIndices", "group___volume.html#ga061c34f8ef3c7bb9cd941db873a36a91", null ],
     [ "operator<", "group___volume.html#ga8da49f5068936374cdd572df6699b4dd", null ],
     [ "operator==", "group___volume.html#gacdc0fc7510e13d480a690d30e2235260", null ],
-    [ "operator<", "group___volume.html#ga5cd7447d3e0ad90168468172f675d359", null ],
-    [ "mcEdges", "namespace_ogre_1_1_volume.html#aaffc813983e56a842801d1c95a0d68a7", null ],
-    [ "mcTriangles", "namespace_ogre_1_1_volume.html#a91eddf9820871324597ceb2bfeacccec", null ],
-    [ "msEdges", "namespace_ogre_1_1_volume.html#aee34e486e74e6a73b85e785f6d0326e2", null ],
-    [ "msTriangles", "namespace_ogre_1_1_volume.html#afba711c74cd63d7159a08e5ed6d91c1c", null ]
+    [ "operator<", "group___volume.html#ga5cd7447d3e0ad90168468172f675d359", null ]
 ];
\ No newline at end of file
